@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with man-db; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
  * Sat Aug 20 15:01:02 BST 1994  Wilf. (G.Wilford@ee.surrey.ac.uk) 
  */
@@ -26,9 +26,6 @@
 #ifndef _HASHTABLE_H
 #define _HASHTABLE_H
 
-#include "libdb/mydbm.h"
-#include "libdb/db_storage.h" 
-
 typedef void (*hash_free_ptr) (void *defn);
 
 struct hashtable {
