@@ -26,36 +26,21 @@
 #endif /* HAVE_CONFIG_H */
 
 #include <stdio.h>
-#include <assert.h>
 #include <errno.h>
 #include <ctype.h>
-
-#if defined(STDC_HEADERS)
 #include <string.h>
 #include <stdlib.h>
-#elif defined(HAVE_STRING_H)
-#include <string.h>
-#elif defined(HAVE_STRINGS_H)
-#include <strings.h>
-#else /* no string(s) header file */
-extern char *strsep();
-#endif /* STDC_HEADERS */
+#include <unistd.h>
 
-#ifdef HAVE_UNISTD_H
-#  include <unistd.h>
-#endif /* HAVE_UNISTD_H */
+#include "xvasprintf.h"
 
-#ifndef STDC_HEADERS
-extern long atol();
-extern char *strsep();
-extern int errno;
-#endif /* not STDC_HEADERS */
-
-#include "lib/gettext.h"
+#include "gettext.h"
 #define _(String) gettext (String)
 
 #include "manconfig.h"
-#include "lib/error.h"
+
+#include "error.h"
+
 #include "mydbm.h"
 #include "db_storage.h"
 
@@ -137,18 +122,14 @@ datum make_multi_key (const char *page, const char *ext)
 	datum key;
 
 	memset (&key, 0, sizeof key);
-	MYDBM_DSIZE (key) = strlen (page) + strlen (ext) + 2;
-	MYDBM_SET_DPTR (key, xmalloc (MYDBM_DSIZE (key)));
-	sprintf (MYDBM_DPTR (key), "%s\t%s", page, ext);
+	MYDBM_SET (key, xasprintf ("%s\t%s", page, ext));
 	return key;
 }
 
 /* allocate a mandata structure */
 struct mandata *infoalloc (void)
 {
-	struct mandata *info = xmalloc (sizeof (struct mandata));
-	memset (info, 0, sizeof *info);
-	return info;
+	return XZALLOC (struct mandata);
 }
 
 /* Free allocated elements of a mandata structure, but not the structure
@@ -259,19 +240,7 @@ datum make_content (struct mandata *in)
 	if (!in->whatis)
 		in->whatis = dash + 1;
 
-	MYDBM_DSIZE (cont) =
-		strlen (dash_if_unset (in->name)) + 1 +
-		strlen (in->ext) + 1 +
-		strlen (in->sec) + 1 +
-		/* strlen (in->_st_mtime) + */ 10 + 1 +
-		/* strlen (in->id) + */ 1 + 1 +
-		strlen (in->pointer) + 1 +
-		strlen (in->filter) + 1 +
-		strlen (in->comp) + 1 +
-		strlen (in->whatis) + 1;
-	MYDBM_SET_DPTR (cont, xmalloc (MYDBM_DSIZE (cont)));
-#ifdef ANSI_SPRINTF
-	MYDBM_DSIZE (cont) = 1 + sprintf (MYDBM_DPTR (cont),
+	MYDBM_SET (cont, xasprintf (
 		"%s\t%s\t%s\t%ld\t%c\t%s\t%s\t%s\t%s",
 		dash_if_unset (in->name),
 		in->ext,
@@ -281,24 +250,7 @@ datum make_content (struct mandata *in)
 		in->pointer,
 		in->filter,
 		in->comp,
-		in->whatis);
-
-	assert (strlen (MYDBM_DPTR (cont)) + 1 == (size_t) MYDBM_DSIZE (cont));
-#else /* !ANSI_SPRINTF */
-	sprintf (MYDBM_DPTR (cont), "%s\t%s\t%s\t%ld\t%c\t%s\t%s\t%s\t%s",
-		 dash_if_unset (in->name),
-		 in->ext,
-		 in->sec,
-		 (long)in->_st_mtime,
-		 in->id,
-		 in->pointer,
-		 in->filter,
-		 in->comp,
-		 in->whatis);
-
-	/* to be sure (st_mtime) */
-	MYDBM_DSIZE (cont) = strlen (MYDBM_DPTR (cont)) + 1;
-#endif /* ANSI_SPRINTF */
+		in->whatis));
 
 #ifdef NDBM
 	/* limit of 4096 bytes of data using ndbm */
@@ -322,8 +274,8 @@ int list_extensions (char *data, char ***names, char ***ext)
 	int count = 0;
 	int bound = 4;	/* most multi keys will have fewer than this */
 
-	*names = xmalloc (bound * sizeof **names);
-	*ext   = xmalloc (bound * sizeof **ext);
+	*names = xnmalloc (bound, sizeof **names);
+	*ext   = xnmalloc (bound, sizeof **ext);
 	while (((*names)[count] = strsep (&data, "\t")) != NULL) {
 		(*ext)[count] = strsep (&data, "\t");
 		if ((*ext)[count])
@@ -333,8 +285,8 @@ int list_extensions (char *data, char ***names, char ***ext)
 
 		if (count >= bound) {
 			bound *= 2;
-			*names = xrealloc (*names, bound * sizeof **names);
-			*ext   = xrealloc (*ext,   bound * sizeof **ext);
+			*names = xnrealloc (*names, bound, sizeof **names);
+			*ext   = xnrealloc (*ext,   bound, sizeof **ext);
 		}
 	}
 
@@ -364,8 +316,7 @@ static struct mandata *dblookup (const char *page, const char *section,
 	memset (&key, 0, sizeof key);
 	memset (&cont, 0, sizeof cont);
 
-	MYDBM_SET_DPTR (key, name_to_key (page));
-	MYDBM_DSIZE (key) = strlen (MYDBM_DPTR (key)) + 1;
+	MYDBM_SET (key, name_to_key (page));
 	cont = MYDBM_FETCH (dbf, key);
 	free (MYDBM_DPTR (key));
 
