@@ -47,7 +47,7 @@
 
 #include "sys/time.h"	/* for time_t */
 
-#include "libdb/mydbm.h"
+#include "mydbm.h"
 
 struct mandata {
 	struct mandata *next;		/* ptr to next structure, if any */
@@ -70,13 +70,13 @@ struct mandata {
 }; 
 
 /* used by the world */
-extern __inline__ struct mandata *dblookup_all (const char *page,
-						const char *section,
-						int match_case);
-extern __inline__ struct mandata *dblookup_exact (const char *page,
-						  const char *section,
-						  int match_case);
-extern int dbstore (struct mandata *in, const char *basename);
+extern inline struct mandata *dblookup_all (const char *page,
+					    const char *section,
+					    int match_case);
+extern inline struct mandata *dblookup_exact (const char *page,
+					      const char *section,
+					      int match_case);
+extern int dbstore (struct mandata *in, const char *base);
 extern int dbdelete (const char *name, struct mandata *in);
 extern void dbprintf (const struct mandata *info);
 extern void free_mandata_elements (struct mandata *pinfo);
@@ -85,10 +85,10 @@ extern void split_content (char *cont_ptr, struct mandata *pinfo);
 extern int compare_ids (char a, char b);
 
 /* local to db routines */
-extern __inline__ void gripe_lock (char *filename);
-extern __inline__ void gripe_corrupt_data (void);
+extern inline void gripe_lock (char *filename);
+extern inline void gripe_corrupt_data (void);
 extern datum make_multi_key (const char *page, const char *ext);
-extern __inline__ struct mandata *infoalloc (void);
+extern inline struct mandata *infoalloc (void);
 extern char *name_to_key (const char *name);
 extern char **split_data (char *content, char *start[]);
 extern datum make_content (struct mandata *in);
