@@ -25,22 +25,16 @@
 #  include "config.h"
 #endif
 
-#include <stdio.h>
-
-#if defined(STDC_HEADERS)
 #include <string.h>
 #include <stdlib.h>
-#elif defined(HAVE_STRING_H)
-#include <string.h>
-#elif defined(HAVE_STRINGS_H)
-#include <strings.h>
-#endif /* STDC_HEADERS */
 
-#include "lib/gettext.h"
+#include "gettext.h"
 #define _(String) gettext (String)
 
 #include "manconfig.h"
-#include "lib/error.h"
+
+#include "error.h"
+
 #include "mydbm.h"
 
 int dbver_rd (MYDBM_FILE dbfile)
@@ -49,8 +43,7 @@ int dbver_rd (MYDBM_FILE dbfile)
 
 	memset (&key, 0, sizeof key);
 
-	MYDBM_SET_DPTR (key, xstrdup (VER_KEY));
-	MYDBM_DSIZE (key) = sizeof VER_KEY;
+	MYDBM_SET (key, xstrdup (VER_KEY));
 
 	content = MYDBM_FETCH (dbfile, key);
 
@@ -77,10 +70,8 @@ void dbver_wr (MYDBM_FILE dbfile)
 	memset (&key, 0, sizeof key);
 	memset (&content, 0, sizeof content);
 
-	MYDBM_SET_DPTR (key, xstrdup (VER_KEY));
-	MYDBM_DSIZE (key) = sizeof VER_KEY;
-	MYDBM_SET_DPTR (content, xstrdup (VER_ID));
-	MYDBM_DSIZE (content) = sizeof VER_ID;
+	MYDBM_SET (key, xstrdup (VER_KEY));
+	MYDBM_SET (content, xstrdup (VER_ID));
 
 	if (MYDBM_INSERT (dbfile, key, content) != 0)
 		error (FATAL, 0,
