@@ -31,6 +31,8 @@
 #  include "config.h"
 #endif /* HAVE_CONFIG_H */
 
+#include <string.h>
+#include <stdlib.h>
 #include <stdio.h>
 #include <ctype.h>
 #include <sys/types.h>
@@ -38,16 +40,6 @@
 #include <errno.h>
 #include <assert.h>
 
-#ifndef STDC_HEADERS
-extern int errno;
-#endif
-
-#ifndef S_ISLNK /* losing sys/stat.h */
-#  if defined(S_IFMT) && defined(S_IFLNK)
-#    define S_ISLNK(mode) (((mode) & S_IFMT) == S_IFLNK)
-#  endif
-#endif
-
 #ifdef HAVE_DIRENT_H
 #  include <dirent.h>
 #else /* not HAVE_DIRENT_H */
@@ -63,47 +55,19 @@ extern int errno;
 #  endif /* HAVE_NDIR_H */
 #endif /* HAVE_DIRENT_H  */
 
-#if defined(STDC_HEADERS)
-#  include <string.h>
-#  include <stdlib.h>
-#elif defined(HAVE_STRING_H)
-#  include <string.h>
-#elif defined(HAVE_STRINGS_H)
-#  include <strings.h>
-#else /* no string(s) header */
-extern char *strrchr();
-extern char *realpath();
-#endif /* no string(s) header */
+#include <unistd.h>
 
-#if defined(HAVE_UNISTD_H)
-#  include <unistd.h>
-#endif /* HAVE_UNISTD_H */
+#include "canonicalize.h"
 
-#if defined(HAVE_LIMITS_H) && defined(_POSIX_VERSION)
-#  include <limits.h>                     /* for PATH_MAX */
-#else /* !(HAVE_LIMITS_H && _POSIX_VERSION) */
-#  include <sys/param.h>                  /* for MAXPATHLEN */
-#endif /* HAVE_LIMITS_H */
-
-#ifndef PATH_MAX
-#  if defined(_POSIX_VERSION) && defined(_POSIX_PATH_MAX)
-#    define PATH_MAX _POSIX_PATH_MAX
-#  else /* !_POSIX_VERSION */
-#    ifdef MAXPATHLEN
-#      define PATH_MAX MAXPATHLEN
-#    else /* !MAXPATHLEN */
-#      define PATH_MAX 1024
-#    endif /* MAXPATHLEN */
-#  endif /* _POSIX_VERSION */
-#endif /* !PATH_MAX */
-
-#include "lib/gettext.h"
+#include "gettext.h"
 #define _(String) gettext (String)
 
 #include "manconfig.h"
-#include "lib/error.h"
-#include "lib/pipeline.h"
-#include "lib/decompress.h"
+
+#include "error.h"
+#include "pipeline.h"
+#include "decompress.h"
+
 #include "security.h"
 #include "ult_src.h"
 
@@ -150,21 +114,21 @@ static char *ult_hardlink (const char *fullpath, ino_t inode)
 		return NULL;
 	}
 
-	ret = strappend (NULL, dir, "/", base, NULL);
+	ret = appendstr (NULL, dir, "/", base, NULL);
 	free (dir);
 	free (base);
 	return ret;
 }
 
-#ifdef S_ISLNK
-/* Use realpath() to resolve all sym links within 'fullpath'.
+/* Resolve all symbolic links within 'fullpath'.
  * Returns a newly allocated string.
  */
 static char *ult_softlink (const char *fullpath)
 {
-	char resolved_path[PATH_MAX];
+	char *resolved_path;
 
-	if (realpath (fullpath, resolved_path) == NULL) {
+	resolved_path = canonicalize_file_name (fullpath);
+	if (!resolved_path) {
 		/* discard the unresolved path */
 		if (quiet < 2) {
 			if (errno == ENOENT)
@@ -180,9 +144,8 @@ static char *ult_softlink (const char *fullpath)
 
 	debug ("ult_softlink: (%s)\n", resolved_path);
 
-	return xstrdup (resolved_path);
+	return resolved_path;
 }
-#endif /* S_ISLNK */
 
 /* Test 'buffer' to see if it contains a .so include. If so and it's not an 
  * absolute filename, return newly allocated string whose contents are the
@@ -261,7 +224,6 @@ const char *ult_src (const char *name, const char *path,
 			}
 		}
 
-#ifdef S_ISLNK
 		/* Permit semi local (inter-tree) soft links */
 		if (flags & SOFT_LINK) {
 			if (S_ISLNK (buf->st_mode)) {
@@ -274,7 +236,6 @@ const char *ult_src (const char *name, const char *path,
 					return NULL;
 			}
 		}
-#endif /* S_ISLNK */
 
 		/* Only deal with local (inter-dir) HARD links */
 		if (flags & HARD_LINK) {
@@ -343,7 +304,7 @@ const char *ult_src (const char *name, const char *path,
 				 * outside the mantree.
 				 */
 				free (base);
-				base = strappend (NULL, path, "/", include,
+				base = appendstr (NULL, path, "/", include,
 						  NULL);
 				free (include);
 
